"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var fs = _interopRequireWildcard(require("fs-extra"));

var path = _interopRequireWildcard(require("path"));

var _changeCase = require("change-case");

var _prompts = _interopRequireDefault(require("prompts"));

var _getModularRoot = _interopRequireDefault(require("./utils/getModularRoot"));

var _execAsync = _interopRequireDefault(require("./utils/execAsync"));

var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));

var _getAllFiles = _interopRequireDefault(require("./utils/getAllFiles"));

var _LineFilterOutStream = _interopRequireDefault(require("./utils/LineFilterOutStream"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const packagesRoot = 'packages';

async function addPackage(destination, typeArg, nameArg, preferOffline = true, verbose = false) {
  const {
    type,
    name
  } = (typeArg && nameArg ? {
    type: typeArg,
    name: nameArg
  } : null) || (await (0, _prompts.default)([{
    name: 'name',
    type: 'text',
    message: `What would you like to name this package?`,
    initial: (0, _changeCase.paramCase)(destination)
  }, {
    name: 'type',
    type: 'select',
    message: `What kind of package is this?`,
    choices: [{
      title: 'A plain package',
      value: 'package'
    }, {
      title: 'A view within an application',
      value: 'view'
    }, {
      title: 'A standalone application',
      value: 'app'
    }],
    initial: 0
  }]));

  if (!['app', 'view', 'package'].includes(type)) {
    throw new Error(`Type ${type} does not exist, please use app, view or package`);
  }

  const modularRoot = (0, _getModularRoot.default)();
  const newComponentName = (0, _changeCase.pascalCase)(name);
  const newPackagePath = path.join(modularRoot, packagesRoot, destination);
  const packageTypePath = path.join(__dirname, '../types', type); // create a new package source folder

  if (fs.existsSync(newPackagePath)) {
    throw new Error(`A package already exists at ${destination}!`);
  }

  fs.mkdirpSync(newPackagePath);
  fs.copySync(packageTypePath, newPackagePath, {
    recursive: true
  });
  const packageFilePaths = (0, _getAllFiles.default)(newPackagePath);

  for (const packageFilePath of packageFilePaths) {
    fs.writeFileSync(packageFilePath, fs.readFileSync(packageFilePath, 'utf8').replace(/PackageName__/g, name).replace(/ComponentName__/g, newComponentName));

    if (path.basename(packageFilePath) === 'packagejson') {
      // we've named package.json as packagejson in these templates
      fs.moveSync(packageFilePath, packageFilePath.replace('packagejson', 'package.json'));
    }
  }

  if (type === 'app') {
    // add a tsconfig, because CRA expects it
    await fs.writeJSON(path.join(newPackagePath, 'tsconfig.json'), {
      extends: path.relative(newPackagePath, modularRoot) + '/tsconfig.json'
    }, {
      spaces: 2
    });
  }

  const yarnArgs = verbose ? ['--verbose'] : ['--silent'];

  if (preferOffline) {
    yarnArgs.push('--prefer-offline');
  }

  const subprocess = (0, _execAsync.default)('yarnpkg', yarnArgs, {
    cwd: modularRoot,
    stderr: verbose ? 'inherit' : 'pipe'
  });

  if (!verbose) {
    var _subprocess$stderr;

    // Remove warnings
    (_subprocess$stderr = subprocess.stderr) === null || _subprocess$stderr === void 0 ? void 0 : _subprocess$stderr.pipe(new _LineFilterOutStream.default(/.*warning.*/)).pipe(process.stderr);
  }

  await subprocess;
}

var _default = (0, _actionPreflightCheck.default)(addPackage);

exports.default = _default;
//# sourceMappingURL=addPackage.js.map