"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createIndex = createIndex;

var fs = _interopRequireWildcard(require("fs-extra"));

var parse5 = _interopRequireWildcard(require("parse5"));

var _escapeStringRegexp = _interopRequireDefault(require("escape-string-regexp"));

var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));

var path = _interopRequireWildcard(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function getEntryPoint(paths, metafile, type) {
  const result = Object.entries(metafile.outputs).find(([key, output]) => {
    return output.entryPoint && path.extname(key) === type;
  });
  const outputFileName = result === null || result === void 0 ? void 0 : result[0];

  if (outputFileName) {
    return path.relative(paths.appBuild, path.join((0, _getModularRoot.default)(), outputFileName));
  } else {
    return undefined;
  }
}

async function createIndex(paths, metafile, replacements, includeRuntime) {
  const index = await fs.readFile(paths.appHtml, {
    encoding: 'utf-8'
  });
  const page = parse5.parse(index);
  const html = page.childNodes.find(node => node.nodeName === 'html');
  const head = html.childNodes.find(node => node.nodeName === 'head');
  const cssEntryPoint = getEntryPoint(paths, metafile, '.css');
  const jsEntryPoint = getEntryPoint(paths, metafile, '.js');

  if (cssEntryPoint) {
    head.childNodes.push(...parse5.parseFragment(`<link rel="stylesheet" href="%PUBLIC_URL%/${cssEntryPoint}"></script>`).childNodes);
  }

  const body = html.childNodes.find(node => node.nodeName === 'body');

  if (jsEntryPoint) {
    body.childNodes.push(...parse5.parseFragment(`<script type="module" src="%PUBLIC_URL%/${jsEntryPoint}"></script>`).childNodes);
  }

  if (includeRuntime) {
    body.childNodes.push(...parse5.parseFragment(`<script type="module" src="%PUBLIC_URL%/_runtime/index.js"></script>`).childNodes);
  }

  let data = parse5.serialize(page); // Run HTML through a series of user-specified string replacements.

  Object.keys(replacements).forEach(key => {
    const value = replacements[key];
    data = data.replace(new RegExp('%' + (0, _escapeStringRegexp.default)(key) + '%', 'g'), value);
  });
  return data;
}
//# sourceMappingURL=api.js.map