"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = init;
exports.initModularFolder = initModularFolder;

var fs = _interopRequireWildcard(require("fs-extra"));

var path = _interopRequireWildcard(require("path"));

var _checkBrowsers = require("./utils/checkBrowsers");

var _execAsync = _interopRequireDefault(require("./utils/execAsync"));

var logger = _interopRequireWildcard(require("./utils/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

async function initModularFolder(folder, initOverride, preferOffline = true, verbose = false) {
  const packageJsonPath = path.join(folder, 'package.json');
  let packageJson;

  try {
    packageJson = await fs.readJSON(packageJsonPath);
  } catch (e) {
    packageJson = {};
  }

  packageJson.modular = {
    type: 'root'
  };
  packageJson.private = true;

  if (!packageJson.workspaces) {
    packageJson.workspaces = ['packages/**'];
  }

  if (!packageJson.browserslist) {
    packageJson.browserslist = _checkBrowsers.defaultBrowsers;
  }

  await fs.writeJSON(packageJsonPath, packageJson, {
    spaces: 2
  }); // now run npm init to ensure that our new content is picked up properly.
  // we don't do this before because npm init prints the package.json to console
  // at the end - so we want our new values to also be picked up.

  const args = ['init'];

  if (initOverride) {
    args.push('-y');
  }

  await (0, _execAsync.default)('npm', args, {
    cwd: folder
  });
  await fs.mkdirp(path.join(folder, 'modular'));
  await fs.mkdirp(path.join(folder, 'packages'));
  const yarnArgs = verbose ? ['--verbose'] : ['--silent'];

  if (preferOffline) {
    yarnArgs.push('--prefer-offline');
  }

  await (0, _execAsync.default)('yarnpkg', yarnArgs, {
    cwd: folder
  });
  logger.log('Modular repository initialized!');
}

function init(initOverride = false, preferOffline = true, verbose = false) {
  return initModularFolder(process.cwd(), initOverride, preferOffline, verbose);
}
//# sourceMappingURL=init.js.map