"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAllWorkspaces = void 0;
exports.getWorkspaceInfo = getWorkspaceInfo;

var _execa = _interopRequireDefault(require("execa"));

var _memoize = _interopRequireDefault(require("./memoize"));

var _getModularRoot = _interopRequireDefault(require("./getModularRoot"));

var logger = _interopRequireWildcard(require("./logger"));

var _stripAnsi = _interopRequireDefault(require("strip-ansi"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function formatYarn1Workspace(stdout) {
  return JSON.parse(stdout);
}

function formatNewYarnWorkspace(stdout) {
  return stdout.split(/\r?\n/).reduce((acc, workspaceString) => {
    const {
      name,
      ...rest
    } = JSON.parse(workspaceString);

    if (rest.location !== '.') {
      acc[name] = rest;
    }

    return acc;
  }, {});
}

const supportedPackageManagers = {
  yarn1: {
    getWorkspaceCommand: 'yarnpkg --silent workspaces info',
    formatWorkspaceCommandOutput: formatYarn1Workspace
  },
  yarn2: {
    getWorkspaceCommand: 'yarnpkg workspaces list --json -v',
    formatWorkspaceCommandOutput: formatNewYarnWorkspace
  },
  yarn3: {
    getWorkspaceCommand: 'yarnpkg workspaces list --json -v',
    formatWorkspaceCommandOutput: formatNewYarnWorkspace
  }
};

async function getCommandOutput(cwd, file, args) {
  const result = await (0, _execa.default)(file, args, {
    cwd,
    reject: false,
    cleanup: true
  });
  const {
    exitCode,
    stdout,
    stderr
  } = result;

  if (stderr && !!exitCode) {
    logger.error(stderr);
    throw new Error(`Failed to lookup yarn workspace information`);
  } // strip out ANSI color codes and escape characters


  return (0, _stripAnsi.default)(stdout);
}

async function getPackageManagerInfo(cwd, packageManager) {
  if (packageManager === 'yarn') {
    const yarnVersion = await getCommandOutput(cwd, 'yarnpkg', ['--version']);

    if (yarnVersion.startsWith('1.')) {
      return supportedPackageManagers.yarn1;
    }

    if (yarnVersion.startsWith('2.')) {
      return supportedPackageManagers.yarn2;
    }

    if (yarnVersion.startsWith('3.')) {
      return supportedPackageManagers.yarn3;
    }
  }

  throw new Error(`${packageManager} is not supported.`);
}

async function getWorkspaceInfo(cwd, packageManager) {
  const packageManagerUtils = await getPackageManagerInfo(cwd, packageManager);
  const [file, ...args] = packageManagerUtils.getWorkspaceCommand.split(' ');
  const workspaceCommandOutput = await getCommandOutput(cwd, file, args);
  return packageManagerUtils.formatWorkspaceCommandOutput(workspaceCommandOutput);
}

function _getAllWorkspaces() {
  const modularRoot = (0, _getModularRoot.default)();
  return getWorkspaceInfo(modularRoot, 'yarn');
}

const getAllWorkspaces = (0, _memoize.default)(_getAllWorkspaces);
exports.getAllWorkspaces = getAllWorkspaces;
//# sourceMappingURL=getAllWorkspaces.js.map