"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = stageView;

var fs = _interopRequireWildcard(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _changeCase = require("change-case");

var _getModularRoot = _interopRequireDefault(require("./getModularRoot"));

var _getAllFiles = _interopRequireDefault(require("./getAllFiles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function stageView(targetedView) {
  const modularRoot = (0, _getModularRoot.default)();

  const tempDir = _path.default.join(modularRoot, 'node_modules', '.modular');

  if (!fs.existsSync(tempDir)) {
    fs.mkdirSync(tempDir);
  }

  const stagedViewAppPath = _path.default.join(tempDir, targetedView);

  if (!fs.existsSync(`${tempDir}/${targetedView}`)) {
    const appTypePath = _path.default.join(__dirname, '../../types', 'app-view');

    fs.mkdirSync(`${tempDir}/${targetedView}`);
    fs.copySync(appTypePath, stagedViewAppPath);
    const packageFilePaths = (0, _getAllFiles.default)(stagedViewAppPath);

    for (const packageFilePath of packageFilePaths) {
      fs.writeFileSync(packageFilePath, fs.readFileSync(packageFilePath, 'utf8').replace(/PackageName__/g, (0, _changeCase.pascalCase)(targetedView)).replace(/ComponentName__/g, (0, _changeCase.pascalCase)(targetedView)));

      if (_path.default.basename(packageFilePath) === 'packagejson') {
        fs.moveSync(packageFilePath, packageFilePath.replace('packagejson', 'package.json'));
      }
    }
  } // This optimizes repeated modular start <view> executions. If a tsconfig.json is present
  // we assume that this view has been staged before and we do not need to write to the index.tsx
  // file or write a tsconfig.json again


  if (!fs.existsSync(_path.default.join(stagedViewAppPath, 'tsconfig.json'))) {
    const indexTemplate = `import * as React from 'react';
import * as ReactDOM from 'react-dom';

import App from '${targetedView}';

ReactDOM.render(
  <App />,
  document.getElementById('root'),
);`;
    fs.writeFileSync(_path.default.join(stagedViewAppPath, 'src', 'index.tsx'), indexTemplate);
    fs.writeJSONSync(_path.default.join(stagedViewAppPath, 'tsconfig.json'), {
      extends: _path.default.relative(stagedViewAppPath, modularRoot) + '/tsconfig.json'
    }, {
      spaces: 2
    });
  }

  return stagedViewAppPath;
}
//# sourceMappingURL=stageView.js.map